@@ -617,33 +617,45 @@ static int pmt_strregmatch(const char *s, const char *pattern, bool icase)
  * no match was found, positive non-zero on success or negative non-zero on
  * failure.
  */
-static bool user_in_sgrp(const char *user, const char *grp, bool icase,
+static bool user_in_sgrp(const char *user, const char *search_grp, bool icase,
     bool regex)
 {
-	struct group *gent;
-	const char *const *wp;
+	const struct group *gent;
+	int i, ret, ngroups = 1;
+	gid_t *grplist, grpbuf;
 
-	if ((gent = getgrnam(grp)) == NULL) {
-		if (errno != 0)
-			w4rn("getgrnam(\"%s\") failed: %s\n",
-			     grp, strerror(errno));
+	ret = getgrouplist(user, -1, &grpbuf, &ngroups);
+	if (ret == 0 || (ret == 1 && grpbuf == -1)) {
+		/* No secondary groups. Cannot be a member, then. */
 		return false;
 	}
-
-	wp = const_cast2(const char *const *, gent->gr_mem);
-	while (wp != NULL && *wp != NULL) {
-		if (regex) {
-			if (pmt_strregmatch(user, *wp, icase) > 0)
-				return true;
-		} else if (icase && strcasecmp(*wp, user) == 0) {
-			return true;
-		} else if (strcmp(*wp, user) == 0) {
-			return true;
-		}
-		++wp;
+	grplist = malloc(sizeof(gid_t) * ngroups);
+	ret = getgrouplist(user, -1, grplist, &ngroups);
+	if (ret < 0) {
+		l0g("getgrouplist(%s) failed: %s\n", user, strerror(errno));
+		free(grplist);
+		return false;
 	}
-
+	for (i = 0; i < ngroups; ++i) {
+		if (grplist[i] == -1)
+			continue;
+		gent = getgrgid(grplist[i]);
+		if (gent == NULL)
+			continue;
+		if (regex) {
+			if (pmt_strregmatch(gent->gr_name, search_grp, icase) > 0)
+				goto found;
+		} else if (icase && strcasecmp(gent->gr_name, search_grp) == 0) {
+			goto found;
+		} else if (strcmp(gent->gr_name, search_grp) == 0) {
+			goto found;
+		}
+	}
+	free(grplist);
 	return false;
+ found:
+	free(grplist);
+	return true;
 }
 
 //-----------------------------------------------------------------------------
@@ -1428,11 +1440,11 @@ static const struct pmt_command default_command[] = {
 	 */
 	{CMD_NFSMOUNT,    "nfs",   {"mount", "%(if %(OPTIONS),-o%(OPTIONS))", "-t%(FSTYPE)", "%(COMBOPATH)", "%(MNTPT)", NULL}},
 	{CMD_NFSMOUNT,    "nfs4"},
-	{CMD_LCLMOUNT,    NULL,    {"mount", "-p0", "%(if %(OPTIONS),-o%(OPTIONS))", "-t%(FSTYPE)", "%(VOLUME)", "%(MNTPT)", NULL}},
+	{CMD_LCLMOUNT,    NULL,    {"mount", "%(if %(OPTIONS),-o%(OPTIONS))", "-t%(FSTYPE)", "%(VOLUME)", "%(MNTPT)", NULL}},
 	{CMD_CRYPTMOUNT,  "crypt", {"mount", "-t", "crypt", "%(if %(CIPHER),-ocipher=%(CIPHER))", "%(if %(FSKEYCIPHER),-ofsk_cipher=%(FSKEYCIPHER))", "%(if %(FSKEYHASH),-ofsk_hash=%(FSKEYHASH))", "%(if %(FSKEYPATH),-okeyfile=%(FSKEYPATH))", "%(if %(OPTIONS),-o%(OPTIONS))", "%(VOLUME)", "%(MNTPT)", NULL}},
 	{CMD_CRYPTMOUNT,  "crypt_LUKS"},
 	{CMD_CRYPTMOUNT,  "crypto_LUKS"},
-	{CMD_CRYPTUMOUNT, "crypt", {"umount.crypt", "%(MNTPT)", NULL}},
+	{CMD_CRYPTUMOUNT, "crypt", {"umount", "%(MNTPT)", NULL}},
 	{CMD_UMOUNT,     NULL,     {"umount", "%(MNTPT)", NULL}},
 	{CMD_FSCK,       NULL,     {"fsck", "-p", "%(FSCKTARGET)", NULL}},
 	{CMD_PMVARRUN,   NULL,     {"pmvarrun", "-u", "%(USER)", "-o", "%(OPERATION)", NULL}},
